| Title: | Accesses the 'ovba' rust library to extract vba binary files |
|---|---|
| Description: | Allows to read the contents of vba binary files. These files contain macro code embedded in Office Open XML. |
| Authors: | Jan Marvin Garbuszus [aut, cre] |
| Maintainer: | Jan Marvin Garbuszus <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.5 |
| Built: | 2026-05-10 09:02:32 UTC |
| Source: | https://github.com/JanMarvin/ovbars |
ovbars allows to parse the OVBA file vbaProject.bin which contains
macro variables in Office Open XML filesovbar_out(): Returns a list of macro sources found in the vba binary.
ovbar_meta(): Returns a list of additional meta data of directories found
in the vba binary. The latter is probably not useful for the user.
ovbar_out(name) ovbar_meta(name)ovbar_out(name) ovbar_meta(name)
name |
the path to the input file |
A named list with character strings. The list is sorted alphabetically.